componenttools.component_to_pitch_and_rhythm_skeleton
=====================================================

.. autofunction:: abjad.tools.componenttools.component_to_pitch_and_rhythm_skeleton.component_to_pitch_and_rhythm_skeleton
